@@ -22,53 +22,50 @@
  * along with MX Snapshot.  If not, see <http://www.gnu.org/licenses/>.
  **********************************************************************/
 
-#include "mainwindow.h"
-#include <unistd.h>
 #include <QApplication>
-#include <QTranslator>
-#include <QLocale>
-#include <QIcon>
-#include <QScopedPointer>
+#include <QCommandLineParser>
 #include <QDateTime>
 #include <QDebug>
+#include <QIcon>
+#include <QLibraryInfo>
+#include <QLocale>
+#include <QScopedPointer>
+#include <QTranslator>
+
+#include <unistd.h>
+#include "mainwindow.h"
+#include "version.h"
 
 static QScopedPointer<QFile> logFile;
 
 void messageHandler(QtMsgType type, const QMessageLogContext &context, const QString &msg);
-void printHelp();
 
 int main(int argc, char *argv[])
 {
-    QApplication a(argc, argv);
+    QApplication app(argc, argv);
+    app.setApplicationVersion(VERSION);
 
-    if (a.arguments().contains("--help") || a.arguments().contains("-h") ) {
-        printHelp();
-        return EXIT_SUCCESS;
-    }
-    if (a.arguments().contains("--version") || a.arguments().contains("-v") ) {
-       system("echo 'Installer version'; dpkg-query -f '${Version}' -W iso-snapshot; echo");
-       return EXIT_SUCCESS;
-    }
+    QCommandLineParser parser;
+    parser.setApplicationDescription(QApplication::tr("Tool used for creating a live-CD from the running system"));
+    parser.addHelpOption();
+    parser.addVersionOption();
+    parser.addOptions({{{"m", "month"}, QApplication::tr("Create a montly snapshot, add 'Month' name in the ISO name, skip used space calculation")},
+                       {{"p", "preempt"}, QApplication::tr("Option to fix issue with calculating checksums on preempt_rt kernels")}});
+    parser.process(app);
 
-    a.setWindowIcon(QIcon::fromTheme("iso-snapshot"));
-
-    QString log_name= "/var/log/iso-snapshot.log";
-    // archive old log
-    system("[ -f " + log_name.toUtf8() + " ] && mv " + log_name.toUtf8() + " " + log_name.toUtf8() + ".old");
-    // Set the logging files
-    logFile.reset(new QFile(log_name));
-    // Open the file logging
-    logFile.data()->open(QFile::Append | QFile::Text);
-    // Set handler
-    qInstallMessageHandler(messageHandler);
+    app.setWindowIcon(QIcon::fromTheme(app.applicationName()));
 
     QTranslator qtTran;
-    qtTran.load(QString("qt_") + QLocale::system().name());
-    a.installTranslator(&qtTran);
+    if (qtTran.load(QLocale::system(), "qt", "_", QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
+        app.installTranslator(&qtTran);
+
+    QTranslator qtBaseTran;
+    if (qtBaseTran.load("qtbase_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
+        app.installTranslator(&qtBaseTran);
 
     QTranslator appTran;
-    appTran.load(QString("iso-snapshot_") + QLocale::system().name(), "/usr/share/iso-snapshot-antix/locale");
-    a.installTranslator(&appTran);
+    if (appTran.load(app.applicationName() + "_" + QLocale::system().name(), "/usr/share/" + app.applicationName() + "/locale"))
+        app.installTranslator(&appTran);
 
     // Check if SQUASHFS is available
     if (system("[ -f /boot/config-$(uname -r) ]") == 0 && system("grep -q ^CONFIG_SQUASHFS=[ym] /boot/config-$(uname -r)") != 0) {
@@ -78,15 +75,22 @@ int main(int argc, char *argv[])
     }
 
     if (getuid() == 0) {
-        MainWindow w(nullptr, a.arguments());
+        QString log_name= "/var/log/" + app.applicationName() + ".log";
+        // archive old log
+        system("[ -f " + log_name.toUtf8() + " ] && mv " + log_name.toUtf8() + " " + log_name.toUtf8() + ".old");
+        // Set the logging files
+        logFile.reset(new QFile(log_name));
+        // Open the file logging
+        logFile.data()->open(QFile::Append | QFile::Text);
+        // Set handler
+        qInstallMessageHandler(messageHandler);
+
+        qDebug().noquote() << app.applicationName() << QApplication::tr("version:") << app.applicationVersion();
+        MainWindow w(nullptr, parser);
         w.show();
-        return a.exec();
+        return app.exec();
     } else {
-        system("su-to-root -X -c " + QCoreApplication::applicationFilePath().toUtf8() + "&");
-//        QApplication::beep();
-//        QMessageBox::critical(nullptr, QApplication::tr("Error"),
-//                              QApplication::tr("You must run this program as root."));
-//        return EXIT_FAILURE;
+        system("su-to-root -X -c " + app.applicationFilePath().toUtf8() + "&");
     }
 }
 
@@ -112,17 +116,7 @@ void messageHandler(QtMsgType type, const QMessageLogContext &context, const QSt
     case QtFatalMsg:    out << "FTL "; break;
     }
     // Write to the output category of the message and the message itself
-    out << context.category << ": "
-        << msg << endl;
-    out.flush();    // Clear the buffered data
+    out << context.category << ": " << msg << endl;
 }
 
-// print CLI help info
-void printHelp()
-{
-    qDebug() << "Usage: iso-snapshot [<options>]\n";
-    qDebug() << "Options:";
-    qDebug() << "  -m --monthly Month   Create a montly snapshot, add 'Month' in the ISO name, skip used space calculation";
-    qDebug() << "  -v --version         Show version information";
-}
 
