@@ -75,9 +75,8 @@
     </message>
     <message>
         <location filename="mainwindow.ui" line="281"/>
-        <location filename="ui_mainwindow.h" line="567"/>
-        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /usr/lib/iso-snapshot/snapshot-exclude.list.</source>
-        <translation>Sie können bestimmte Verzeichnisse ausschliessen durch anklicken der Auswahlfelder oder mittels des Schaltknopfs direkt die Datei /usr/lib/iso-snapshot/snapshot-exclude.list bearbeiten.</translation>
+        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /usr/local/share/excludes/iso-snapshot-exclude.list.</source>
+        <translation>Sie können bestimmte Verzeichnisse ausschliessen durch anklicken der Auswahlfelder oder mittels des Schaltknopfs direkt die Datei /usr/local/share/excludes/iso-snapshot-exclude.list bearbeiten.</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="338"/>
@@ -469,6 +468,11 @@ gespeicherte Kopien von früheren Schnappschüssen löschen:
         <source>Are you sure you want to quit the application?</source>
         <translation>Sicherheitsabfrage: Programm wirklich beenden? </translation>
     </message>
+    <message>
+        <location filename="ui_mainwindow.h" line="567"/>
+        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /usr/lib/iso-snapshot/snapshot-exclude.list.</source>
+        <translation>Sie können bestimmte Verzeichnisse ausschliessen durch anklicken der Auswahlfelder oder mittels des Schaltknopfs direkt die Datei /usr/lib/iso-snapshot/snapshot-exclude.list bearbeiten.</translation>
+    </message>
 </context>
 <context>
     <name>QApplication</name>
