@@ -75,9 +75,8 @@
     </message>
     <message>
         <location filename="mainwindow.ui" line="281"/>
-        <location filename="ui_mainwindow.h" line="567"/>
-        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /usr/lib/iso-snapshot/snapshot-exclude.list.</source>
-        <translation>Μπορείτε επίσης να εξαιρεθούν ορισμένες καταλόγους τσεκάροντας τις κοινές επιλογές παρακάτω, ή κάνοντας κλικ στο κουμπί για να επεξεργαστείτε άμεσα /usr/lib/iso-snapshot/snapshot-exclude.list</translation>
+        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /usr/local/share/excludes/iso-snapshot-exclude.list.</source>
+        <translation>Μπορείτε επίσης να εξαιρεθούν ορισμένες καταλόγους τσεκάροντας τις κοινές επιλογές παρακάτω, ή κάνοντας κλικ στο κουμπί για να επεξεργαστείτε άμεσα /usr/local/share/excludes/iso-snapshot-exclude.list.</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="338"/>
@@ -468,6 +467,11 @@
         <source>Are you sure you want to quit the application?</source>
         <translation>Είστε βέβαιοι ότι θέλετε να τερματίσετε την εφαρμογή</translation>
     </message>
+    <message>
+        <location filename="ui_mainwindow.h" line="567"/>
+        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /usr/lib/iso-snapshot/snapshot-exclude.list.</source>
+        <translation>Μπορείτε επίσης να εξαιρεθούν ορισμένες καταλόγους τσεκάροντας τις κοινές επιλογές παρακάτω, ή κάνοντας κλικ στο κουμπί για να επεξεργαστείτε άμεσα /usr/lib/iso-snapshot/snapshot-exclude.list</translation>
+    </message>
 </context>
 <context>
     <name>QApplication</name>
