@@ -75,9 +75,8 @@
     </message>
     <message>
         <location filename="mainwindow.ui" line="281"/>
-        <location filename="ui_mainwindow.h" line="567"/>
-        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /usr/lib/iso-snapshot/snapshot-exclude.list.</source>
-        <translation>Du kan också undanta speciella kataloger genom att kryssa för de vanliga valen nedan, eller genom att klicka på knappen för att direkt redigera /usr/lib/iso-snapshot/snapshot-exclude.list.</translation>
+        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /usr/local/share/excludes/iso-snapshot-exclude.list.</source>
+        <translation>Du kan också undanta speciella kataloger genom att kryssa för de vanliga valen nedan, eller genom att klicka på knappen för att direkt redigera  /usr/local/share/excludes/iso-snapshot-exclude.list.</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="338"/>
@@ -469,6 +468,11 @@ genom att avlägsna tidigare snapshots och sparade kopior:
         <source>Are you sure you want to quit the application?</source>
         <translation>Är du säker på att du vill avsluta programmet?</translation>
     </message>
+    <message>
+        <location filename="ui_mainwindow.h" line="567"/>
+        <source>You can also exclude certain directories by ticking the common choices below, or by clicking on the button to directly edit /usr/lib/iso-snapshot/snapshot-exclude.list.</source>
+        <translation>Du kan också undanta speciella kataloger genom att kryssa för de vanliga valen nedan, eller genom att klicka på knappen för att direkt redigera /usr/lib/iso-snapshot/snapshot-exclude.list.</translation>
+    </message>
 </context>
 <context>
     <name>QApplication</name>
